---
title: "K-ISMS-P"
description: "Terraform compliance scanning for K-ISMS-P — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Team" variant="caution" />
<Badge text="Government" variant="tip" />

**Issuing body:** [KISA](https://www.kisa.or.kr)
**Jurisdiction:** Country — Asia-Pacific
**Countries:** KR


## Assessment

Assess your infrastructure against K-ISMS-P for free at any tier:

```bash
complyform assess --frameworks=k_isms_p
```

## Remediation

Requires Team tier or higher ($1,999/yr) for remediation.

```bash
complyform remediate --frameworks=k_isms_p
```

## Related Frameworks

- [IRAP](/frameworks/irap)
- [MTCS SS](/frameworks/mtcs)
- [OSPAR](/frameworks/ospar)
- [ISMAP](/frameworks/ismap)
